# Literature Review

There is a significant amount of literature written on open access journal publication, including work that focuses on OA models that employ article processing charges (APCs) to finance publication. OA journals are most prominent in the science, technology, and medicine (STM) fields, where they are most commonly funded by APCs \cite{Solomon_2012}. In 2010, Björk, et al. found that within these particular fields, “The weighted average OA availability over all [STM] disciplines was 20.4%.” Among life sciences journals, gold OA (immediate, free access to a publication) is more prevalent than green OA publishing (self-archiving a version of a manuscript) \cite{Bj_rk_2010}. Solomon and Björk (2012) report that in 2011 there were a total of 1,825 journals in the cross-discplinary OA journal index DOAJ charging APCs, better than 26% of journals indexed there. Of the journals studied, the largest number of them charged APCs in the $601-$800 range. Solomon and Bjork also found that universities in general have a lower article processing charge ($461 USD on average) as opposed to commercial publishers. \cite{Solomon_2012} The range of APCs is vast; they "...vary quite dramatically...” from $800 for certain Hindawi publications, to $5,000 for _Cell Reports_ (both OA) \cite{Mangiafico_2014}.

APCs are just one option in a broad landscape of publication funding models. Lack of transparency of publisher costs, however, has prevented a general consensus on the expense of producing a journal. As Van Noorden (2013) notes: for-profit journals are “...even less transparent about their costs than their open-access counterparts. Most declined to reveal prices or costs when interviewed for [Van Noorden’s] article” \cite{Van_Noorden_2013}. Nevertheless, attempts to understand and evaluate publishing costs have been made many times, mostly by utilizing rough estimates. In his analysis of costs incurred in creating and maintaining a peer-reviewed journal, Clarke (2007) created a framework to categorize and monetize  necessary tasks--from receipt of a manuscript to publication (focused mainly on electronic tools and dissemination) \cite{Clarke_2007}. Clarke’s cost model consists of Establishment costs, Operations costs (submissions-related, article-related, and generic costs), Infrastructure Maintenance, and Financial Aspects. Clarke also makes the distinction between fixed and variable costs: fixed costs are ongoing and “...are associated with the creation, existence and sustenance of an operation, and are independent of the volume of production,” whereas variable costs relate to volume (of submissions, of accepted papers, of published papers, etc). Using these components he estimated costs for set-up and maintenance of an online journal in various scenarios (not-for-profit publishers, for-profit publishers, among others). Using a per article APC of $730 Clarke estimated it would cost $22,000 per year to run an OA journal. Hovav and Gray (2001) reported on a case study which set out to analyze the fee and management structure of six ejournals. While none of the journals studied utilized APCs as a supplemental source of revenue, the range of cost to produce ejournals ranged from “minimal, voluntary” to “$25,000” per year \cite{Hovav_2001}. King (2007) estimated that “...the average fixed cost to publish an article would be $3,000 per article,” which would essentially just cover fixed costs and not take into account variable costs, which he notes "...are affected by the size of an organization, inefficiencies, and R&D capabilities." \cite{King_2007}. Hedlund and Gustafsson (2004) surveyed editors of open access scientific journals in an attempt to understand the cost structure based on either direct publishing costs or time estimates for task completion related to publication. Using a time-as-cost model, they came to the conclusion that about 163 hours are spent per year on tasks such as administration, IT-infrastructure, planning issues, and marketing to authors and readers \cite{Hedlund_2004}. This figure reflects hours spent on an already established journal, where set-up and establishment efforts have already been completed. Further, Hedlund and Gustafsson surveyed editors who, in many cases, likely deal more closely with content-related duties and less with the administration and operation of the technological infrastructure and/or other publication management tasks. Included in publication management tasks is the oversight and coordination of post-acceptance manuscript preparation, whether this work is accomplished in-house or through a vendor. As Solomon and Björk (2012) found, a large portion of smaller-scale OA publishers make the decision to contract outside vendors for operations like copyediting and typesetting, most often because the capability to do so in-house is not available \cite{Solomon_2012}. This necessarily adds another direct cost associated with publication for those smaller or newer publishing ventures that do not have the staff or capability to perform copyediting and typesetting.

Library-based publishing operations often do not have the capability to take on the task of copyediting and typesetting for the reasons mentioned above. In many cases these operations support open access to research produced at the institution. In their article “Libraries as Journal Publishers” (2011) Maughan Perry, et al. discuss the different roles that libraries can and do play in the creation and support of scholarly journals beyond publication \cite{Maughan_Perry_2011}: increasing discoverability of content; advising on author rights, author agreements, and licensing options such as Creative Commons; ISSN registration; DOI assignment; software services and support; formulation of outreach strategies; and training of editorial staff on publication platform. Many of these tasks taken on by library publishing operations to support OA publications are uniquely relevant to libraries (and libraries functioning as journal publishers) because, by definition, libraries are “mission driven, rather than market driven, [are] strong supporters of intellectual freedom, and [are] opponents of censorship and other restrictions on access to knowledge” \cite{Mangiafico_2014}. In 2008 Karla Hahn surveyed the member institutions of the Association of Research Libraries to gauge the level of involvement or interest in library-based publishing. Of the 80 libraries surveyed, 44% were actively involved in library publishing at the time of the survey, and 21% were in the planning phases of beginning such a program \cite{Hahn_2008}. Mullins, et al. (2012) also surveyed libraries to better understand the current landscape of libraries that publish academic journals. Of the 43 large research libraries surveyed, 55% were either involved in, or interested and willing to become involved in, journal publication support, and “About three-quarters of the programs publish between one and six journals, the majority of which are only distributed electronically and are less than three-years old” \cite{Mullins_2012}. York University’s library publishing operation is one such venture that exceeds these reported numbers; as of 2010 the York Digital Journals (YDJ) program was publishing 18 journals after about 4 years of existence. The YDJ project benefitted from native library infrastructure; the University landscape was crucial to the early success of the operation because it provided the journals program with “...multiple layers of support from library and university administration, as well as faculty members, librarian mentors, and library computing services” \cite{Kosavic_2010}. More recently, a survey conducted by the Library Publishing Coalition (LPC) project yielded 110 institutional responses and data on 565 published journals, most of which were faculty-driven. Similar to YDJ, 90% of libraries responding to the LPC survey rely (in part or totally) on “...their library’s operating budget to support publishing services” \cite{Library_Publishing_2014}. 

Also like the YDJ, many library-based (and commercial) publishing operations rely on freely available, open source software, such as Open Journal Systems (OJS), as a publishing platform (Figure \ref{fig:tremorsnap}). OJS is “...a robust, standards-based, publication-management system for scholarly journals, providing editorial workflow management, online article access, full-text searching, and interactive reading tools” \cite{Devakos_2007}. Of the libraries surveyed for the research report “Library Publishing Services: Strategies for Success,” 57% used OJS for electronic publication \cite{Mullins_2012}. These numbers are consistent with the findings of Hahn’s 2008 ARL report, which found that more than half (about 55%) of the surveyed libraries active in scholarly publishing utilized OJS \cite{Hahn_2008}. The LPC’s directory reported that 45% of surveyed libraries utilized OJS; it was the most common platform among respondents \cite{Library_Publishing_2014}. While this software is open source and free to use and build upon, there are often “...some considerable recurrent costs [...] involved in the development and operation of the publisher’s online access systems” \cite{Houghton_2009}. This tends to include multiple rounds of customizations and continual updates to the system, as recorded by Clarke (2007) who incorporates into the cost of publishing an electronic journal “...sustaining the technical infrastructure and the intellectual infrastructure on which the journal’s operation depends” \cite{Clarke_2007}. As Kosavic (2010) discovered with the YDJ project, the use of Open Journal Systems is often not just a straight-forward install, requiring staff to perform necessary upkeep. After the initial set up, the faculty at York University “...began to ask for added functionality and to request customizations to the software, which resulted in the need for programming time” \cite{Kosavic_2010}.

In addition to customizing the OJS interface to meet publishing goals, libraries have made concerted efforts to utilize available technology to further support mission-related goals: acknowledging preservation as a function of scholarly publishing, and ensuring long term, permanent archival storage of and access to published content. These principles are oftentimes manifested in the form of institutional repositories (IRs). Many IRs run on DSpace, an open source software application that can be used to create an “out of the box” install, a highly customized digital repository, or something in between. Hahn (2008) found DSpace to be the second-most utilized software program that libraries used to support their publishing services (behind OJS) \cite{Hahn_2008}. These findings were echoed by Mullins, et al. who also found DSpace to be second to OJS for library publishing purposes, at 36% \cite{Mullins_2012}. As Houghton, et al. (2009) observed, “Enabling and supporting self-archiving through the operation of institutional repositories offers a number of potential benefits for universities and research institutions, not only through providing greater support to research, but also in providing a platform for hosting and showcasing the institutions research and maintaining a more complete record of it…” \cite{Houghton_2009}. In addition to institutional repositories, which house a broad range of disciplines, subject-specific repositories exist to aggregate content into discipline specific pools of information for potential researchers. PubMed Central (PMC) fills this role for life sciences journals; when studying OA scientific literature Björk, et al. (2010) found PMC to be the most frequently encountered subject based repository, along with arXiv \cite{Bj_rk_2010}. Standards for inclusion in a repository vary. Within PMC, once a publication is accepted for inclusion there are certain requirements that must be met in order for each article to be properly ingested into the system, like the “...conversion of submitted material into highly structured and tagged ASCII text” \cite{Fisher_2008}. Fisher (2008) cites this work to make content fit for inclusion in PMC as an added cost of publication that can be, and often is, accommodated through outsourcing copyediting and typesetting to a vendor that understands the nuances behind "More complex document tagging definitions (such as the US National Library of Medicine DTD)” \cite{Fisher_2008}.
